/******************************************************************************
 *
 * Copyright:
 *    (C) 2008 Embedded Artists AB
 *
 * Description:
 *    Main program for I2C_LEDs_KEYs demo
 *
 *****************************************************************************/

#include <general.h>
#include <printf_P.h>
#include <ea_init.h>
#include <lpc2xxx.h>
#include <consol.h>
#include "i2c.h"
#include "pca9532.h"

#define STEP_DELAY 50
#define KEY_LEFT   0x0080
#define KEY_RIGHT  0x0100


/*****************************************************************************
 *
 * Description:
 *    Delay execution by a specified number of milliseconds by using
 *    timer #1. A polled implementation.
 *
 * Params:
 *    [in] delayInMs - the number of milliseconds to delay.
 *
 ****************************************************************************/
static void
delayMs(tU16 delayInMs)
{
  /*
   * setup timer #1 for delay
   */
  T1TCR = 0x02;          //stop and reset timer
  T1PR  = 0x00;          //set prescaler to zero
  T1MR0 = delayInMs * (CORE_FREQ / PBSD / 1000);
  T1IR  = 0xff;          //reset all interrrupt flags
  T1MCR = 0x04;          //stop timer on match
  T1TCR = 0x01;          //start timer
  
  //wait until delay time has elapsed
  while (T1TCR & 0x01)
    ;
}

/*****************************************************************************
 *
 * Description:
 *    The first function to execute 
 *
 ****************************************************************************/
int
main(void)
{
  tU8 pca9532Present;

  eaInit();   //initialize printf
  i2cInit();  //initialize I2C

  printf("\n\n\n\n\n*******************************************************\n");
  printf("*                                                     *\n");
  printf("* Test program for 'Experiment Expansion Board'       *\n");
  printf("* running on LPC2103 Education Board.                 *\n");
  printf("* I2C LEDs and Keys demo                              *\n");
  printf("*                                                     *\n");
  printf("* (C) Embedded Artists 2008                           *\n");
  printf("*                                                     *\n");
  printf("*******************************************************\n");

  //check if connection with PCA9532
  pca9532Present = pca9532Init();
  
	while(1)
	{
    tU16 keys;

	  if (TRUE == pca9532Present)
	  {
	    if (!(keys & KEY_LEFT))  setPca9532Pin(0, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(8, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(1, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(9, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(2, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(10, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(3, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(11, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(4, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(12, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(5, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(13, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(6, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(14, 0);
      delayMs(STEP_DELAY);
	    if (!(keys & KEY_LEFT))  setPca9532Pin(7, 0);
	    if (!(keys & KEY_RIGHT)) setPca9532Pin(15, 0);
      delayMs(STEP_DELAY);
	    setPca9532Pin(0, 1);
	    setPca9532Pin(1, 1);
	    setPca9532Pin(2, 1);
	    setPca9532Pin(3, 1);
	    setPca9532Pin(4, 1);
	    setPca9532Pin(5, 1);
	    setPca9532Pin(6, 1);
	    setPca9532Pin(7, 1);
	    setPca9532Pin(8, 1);
	    setPca9532Pin(9, 1);
	    setPca9532Pin(10, 1);
	    setPca9532Pin(11, 1);
	    setPca9532Pin(12, 1);
	    setPca9532Pin(13, 1);
	    setPca9532Pin(14, 1);
	    setPca9532Pin(15, 1);
      delayMs(STEP_DELAY);
      keys = ~getPca9532Pin();
      printf("\n%x", keys);
    }
  }
}
